@@ -20,6 +20,7 @@ import qualified PMS.Infra.ProcSpawn.App.Control as IPS
 import qualified PMS.Infra.Serial.App.Control as SER
 import qualified PMS.Infra.Socket.App.Control as SCK
 import qualified PMS.Infra.Watch.App.Control as IWA
+import qualified PMS.Infra.FileSystem.App.Control as IFS
 import qualified PMS.Domain.Service.App.Control as DSR
 
 #ifdef mingw32_HOST_OS
@@ -32,9 +33,9 @@ import qualified PMS.Infrastructure.App.Control as INF
 main :: IO ()
 main = getArgs >>= \args -> do
 #ifdef mingw32_HOST_OS
-  let apps = [URQ.run, URS.run, UNO.run, ICR.run, IPS.run, IWA.run, DSR.run, SCK.run, SER.run]
+  let apps = [URQ.run, URS.run, UNO.run, ICR.run, IPS.run, IWA.run, IFS.run, DSR.run, SCK.run, SER.run]
 #else
-  let apps = [URQ.run, URS.run, UNO.run, ICR.run, IPS.run, IWA.run, DSR.run, SCK.run, SER.run, INF.run]
+  let apps = [URQ.run, URS.run, UNO.run, ICR.run, IPS.run, IWA.run, IFS.run, DSR.run, SCK.run, SER.run, INF.run]
 #endif
   flip E.catchAny exception
      $ flip E.finally finalize
